CLIP<sup>n</sup> is a Python package for integrating phenotypic screening data generated from diverse experimental setups. It provides tools for data
integration for reference compound profiles and predictions for uncharacterized compounds.
